@@ -28,7 +28,7 @@ Moose::Exporter->setup_import_methods(
     as_is => [qw/get_options/],
 );
 
-our $VERSION = version->new('0.3.9');
+our $VERSION = version->new('0.4.0');
 our $EXIT    = 1;
 
 has options => (
@@ -135,7 +135,7 @@ around BUILDARGS => sub {
             'help',
             'man',
             'version',
-            'auto_complete|auto-complete',
+            'auto_complete|auto-complete=i',
             'auto_complete_list|auto-complete-list!',
         );
     }
@@ -313,7 +313,15 @@ sub process {
         last if $action eq 'last';
     }
 
-    $self->cmd( shift @{ $self->files } ) if @{ $self->files } && $self->sub_command;
+    if ( $self->sub_command ) {
+        shift @{ $self->files } if @{ $self->files } && $self->files->[0] eq '--';
+
+        if ( !@{ $self->files } && @args ) {
+            $self->files([ @args ]);
+        }
+
+        $self->cmd( shift @{ $self->files } ) if @{ $self->files };
+    }
     if ( !$passed_args && $self->files ) {
         @ARGV = ( @{ $self->files }, @args );  ## no critic
     }
@@ -380,7 +388,7 @@ sub process {
 sub complete {
     my ($self, $errors) = @_;
 
-    if ( $self->sub_command && !$self->cmd && !$self->sub_command->{ $self->cmd } ) {
+    if ( $self->sub_command && !$self->cmd ) {
         my $cmd = $ARGV[1];
         my @sub_command = grep { $cmd ? /$cmd/ : 1 } sort keys %{ $self->sub_command };
         print join ' ', @sub_command;
@@ -510,7 +518,7 @@ Getopt::Alt - Command line option passing with with lots of features
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt version 0.3.9.
+This documentation refers to Getopt::Alt version 0.4.0.
 
 =head1 SYNOPSIS
 
@@ -787,10 +795,24 @@ Returns a list of all command line options in the current object.
 
 =head3 C<best_option ()>
 
+Decides on the best matching option.
+
 =head3 C<complete ()>
 
 Command line auto complete helper
 
+=head2 Auto Complete
+
+For your program (say eg) you can add the following to your C<~/.bashrc>
+file to get auto-completion.
+
+    _eg() {
+        COMPREPLY=($(vtide --auto-complete ${COMP_CWORD} -- ${COMP_WORDS[@]}))
+    }
+    complete -F _eg eg
+
+B<Note>: This is different from version 0.4.0 and earlier
+
 =head1 DIAGNOSTICS
 
 =head1 CONFIGURATION AND ENVIRONMENT
